.. _curlshareobject:

CurlShare Object
================

.. autoclass:: pycurl.CurlShare

    CurlShare objects have the following methods:

    .. automethod:: pycurl.CurlShare.close

    .. autoattribute:: pycurl.CurlShare.closed

    .. automethod:: pycurl.CurlShare.setopt

    .. automethod:: pycurl.CurlShare.share

    .. automethod:: pycurl.CurlShare.unshare
